(* OcamlHTML - A library for generating HTML page and build CGI scripts
 *
 * cgi.mli - 10/9/2000
 * CGI interface
 *
 * Warning: this library uses optional arguments to make life easier
 *
 * Copyright (C) 2000 Antoine Mine' (mine@di.ens.fr)
 *)


(** Environement and argument query from CGI-scripts. 
   
   These implementation is based on RFC 2616 ([HTTP/1.1]) and
   RFC 2112 (MIME mupltipart), and the Perl5 CGI library.
*)


open Html


val get_cgi_server_software: unit -> string
(** Returns ["Unknown"] if the value is unknown. *)

val get_cgi_server_name:     unit -> string
(** Returns ["Unknown"] if the value is unknown. *)

val get_cgi_server_protocol: unit -> string
(** Returns ["Unknown"] if the value is unknown. *)

val get_cgi_method: unit -> Html.form_method
(** Raises Not_found if [REQUEST_METHOD] is set not to [GET], [POST] 
   or it is unset. *)

val get_cgi_query:           unit -> string
val get_cgi_path_info:       unit -> string
val get_cgi_path_translated: unit -> string
val get_cgi_script_name:     unit -> string

val get_cgi_self_url: unit -> string
(** This is not reliable. *)

val get_cgi_remote_host: unit -> string
(** Tries to get the hostname, if unsuccessful, get the IP. *)

val get_cgi_remote_port: unit -> (int option)

val get_cgi_length:       unit -> (int option)
(** Only set with [Post] method *)

val get_cgi_content_type: unit -> string
(** Only set with [Post] method *)


val get_cgi_header: string -> (string option)
(** Gets custom HTTP header, or [None] if not present.
   
   The header name is converted into a environment variable
   by uppercasing, changing - into _ and appending HTTP_
*)

val get_cgi_accept:     unit -> (string option)
(** Gets the [accept] HTTP header. *)

val get_cgi_user_agent: unit -> (string option)
(** Gets the [user-agent] HTTP header. *)

val is_cgi_accept: string -> bool
(** Returns true if the mime type is accepted. *)

val get_cgi_args: ?maxlength:int -> unit -> (string*(string option)) list
(** Returns the parsed CGI arguments as a pairs
   [(key,val)] meaning that the form component named [key] has associated value
   [val] (which can be [None], or [Some s] where [s] is a string).
   It works for [POST], [GET] and multipart [POST] methods.
   [maxlength] is used to raise an exception if the size of the data exceeds
   [maxlength] bytes (useful to prevent malicious clients from overloading 
   the server).
*)


val build_cgi_url: ?script:string -> ?path:string ->
                   ?args:(string*string option) list -> unit -> string
(** Builds the URL for a script.
   If called from a CGI-script, default script name path and arguments are 
   thoses of the current script invocation.
   This is the converse of {!Cgi.get_cgi_args}.
*)

val get_cgi_cookies: unit -> (string*string option) list
(** Returns the cookies the CGI-script was called with in a list of pairs
   [(name,value)].
*)

val set_timeout: int -> unit
(** After the specified number of seconds, abort and display an error WEB page.
   Disable the previous timeout if 0.
   This is useful to prevent malicious clients from overloading the server.
*)

