(* OcamlHTML - A library for generating HTML page and build CGI scripts
 *
 * date.mli - 10/9/2000
 * Date manipulation interface (according to RFC 1123)
 *
 * only dates after 1900 are supported !
 *
 * Warning: this library uses optional arguments to make life easier
 *
 * Copyright (C) 2000 Antoine Mine' (mine@di.ens.fr)
*)

(** Simple RFC 1123-like date manipulation. 

   This implementation is based on RFC 1123 (Internet date manipulation).
*)


(** Abstract date type. *)
type date

val to_string: date -> string
(** Converts a date into a string day, "dd mm yyyy hh:mm:ss GMT"
   raises [Invalid_argument] for malformed date!
*)

(* Get current date 
   the returned date is _always_ well-formed! *)
val get_date: unit -> date
(** Get the current date. *)

val build_date: 
    ?timezone:int (* optional hour shift, simply added to the hour *)
 -> ?mili: int  (* miliseconds, in 0..999 (optional) *)
 -> int  (* year (must be >1900) *)
 -> int  (* month in 1=Jan...12=Dec *)
 -> int  (* day in 1..31 *)
 -> int  (* hour in 0..23 *)
 -> int  (* min in 0..59 *)
 -> int  (* sec in 0..59 *)
 -> date
(** [build_date year month day hour min sec] builds a new date, 
   with optional timezone (specified as a hour shift). 
   [year] must be greater than 1990.
   [month] is in 1..12.
   [day] is in 1..31.
   [hour] is in 0..23.
   [min] is in 0..59.
   [sec] is in 0..59.
*)


(** Date manipulation functions. *)

val add_years: date->int -> unit
val add_months: date->int -> unit
val add_days: date->int -> unit
val add_hours: date->int -> unit
val add_minutes: date->int -> unit
val add_seconds: date->int -> unit

val from_string: string -> date
(** Parse a date.
   It is supposed to work only for dates obtained from [to_string]. *)


(** Date comparison functions. *)

val is_before: date -> date -> bool
val is_same: date -> date -> bool



