(* OcamlHTML - A library for generating HTML page and build CGI scripts
 *
 * This cookie server is triggered by an url built by 
 * Sscookie.content_from_string.
 * It sends back to the content of the file, or an error message if it is
 * unavailable.
 * It is also this server's responsability to clean outdated cookies.
 *
 * Warning: this library uses optional arguments to make life easier
 *
 * Copyright (C) 2000 Antoine Mine' (mine@di.ens.fr)
 *)

open Http;;
open Html;;
open Cgi;;
open Date;;
open Sscookie;;

let error () =
  http_header ();
  html_begin "Sserver Error";
  h1 "Server-Side Cookie Error";
  p "The temporary document you have requested is no longer available, or is invalid. Please resubmit your request.";
  html_end ();
  exit 0;;


let main() = 
  let file = ref ""
  and key = ref ""
  and ok = ref false
  in

  List.iter (function 
      ("name",Some s) -> file:=s
    | ("key",Some s) -> key:=s
    | _ -> ())
    (get_cgi_args());
  
  if !file="" || !key="" then error();

  (* clean_cookies () *)

  try
    let rec toto = function
	[] -> []
      |	("Key",s)::a -> if !key<>s then error(); toto a
      |	a::b -> a::(toto b) in
    let headers = toto (get_headers !file) in
    let f = get_contents !file in
    print_string "Status: 200 OK\r\n";
    List.iter (function (a,b) -> Printf.printf "%s: %s\r\n" a b) headers;
    print_string "\r\n";
    let len = (in_channel_length f)-(pos_in f) in
    let c = String.create len in
    really_input f c 0 len;
    print_string c;
    Unix.lockf (Unix.descr_of_in_channel f) Unix.F_ULOCK 0;
    close_in f
 
  with _ -> error ();;


main();;
